# ISY994v5

Class based interface to the ISY994 device with V5 firmware.

Provides a common interface to all devices, variables, programs, and scenes on an ISY controller. 

Currently supports Insteon dimmers, switches, keypadlincs, fanlincs. 

Designed to be easy to expand support to other device types.
